@@ -18,6 +18,7 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KProtocolInfo>
 #include <KSharedConfig>
 
 #include <KActivities/Consumer>
@@ -37,6 +38,7 @@ using namespace KAStats::Terms;
 
 QString agentForUrl(const QString &url)
 {
+    QUrl u(url);
     // clang-format off
     return url.startsWith(QLatin1String("ktp:"))
                 ? AGENT_CONTACTS
@@ -48,6 +50,8 @@ QString agentForUrl(const QString &url)
                 ? AGENT_DOCUMENTS
          : (url.startsWith(QLatin1String("file:/")) && !url.endsWith(QLatin1String(".desktop")))
                 ? AGENT_DOCUMENTS
+         : (u.scheme() != QLatin1String("file") && !u.scheme().isEmpty() && KProtocolInfo::isKnownProtocol(u.scheme()))
+                  ? AGENT_DOCUMENTS
          // use applications as the default
                 : AGENT_APPLICATIONS;
     // clang-format on
@@ -79,7 +83,7 @@ public:
             }
 
             if (!entry || !entry->isValid()) {
-                qWarning() << "Entry is not valid" << id << entry;
+                qCWarning(KICKER_DEBUG) << "Entry is not valid" << id << entry;
                 m_id = id;
                 return;
             }
@@ -139,7 +143,7 @@ public:
         return NormalizedId(this, id);
     }
 
-    QSharedPointer<AbstractEntry> entryForResource(const QString &resource) const
+    QSharedPointer<AbstractEntry> entryForResource(const QString &resource, const QString &mimeType = QString()) const
     {
         using SP = QSharedPointer<AbstractEntry>;
 
@@ -150,9 +154,9 @@ public:
 
         } else if (agent == AGENT_DOCUMENTS) {
             if (resource.startsWith(QLatin1String("/"))) {
-                return SP(new FileEntry(q, QUrl::fromLocalFile(resource)));
+                return SP(new FileEntry(q, QUrl::fromLocalFile(resource), mimeType));
             } else {
-                return SP(new FileEntry(q, QUrl(resource)));
+                return SP(new FileEntry(q, QUrl(resource), mimeType));
             }
 
         } else if (agent == AGENT_APPLICATIONS) {
@@ -167,7 +171,7 @@ public:
         }
     }
 
-    Private(KAStatsFavoritesModel *parent, QString clientId)
+    Private(KAStatsFavoritesModel *parent, const QString &clientId)
         : q(parent)
         , m_query(LinkedResources | Agent{AGENT_APPLICATIONS, AGENT_CONTACTS, AGENT_DOCUMENTS} | Type::any() | Activity::current() | Activity::global()
                   | Limit::all())
@@ -205,7 +209,7 @@ public:
 
         for (const auto &result : results) {
             qCDebug(KICKER_DEBUG) << "Got " << result.resource() << " -->";
-            addResult(result.resource(), -1, false);
+            addResult(result.resource(), -1, false, result.mimetype());
         }
 
         // Normalizing all the ids
@@ -240,7 +244,7 @@ public:
         qCDebug(KICKER_DEBUG) << "After ordering: " << itemStrings;
     }
 
-    void addResult(const QString &_resource, int index, bool notifyModel = true)
+    void addResult(const QString &_resource, int index, bool notifyModel = true, const QString &mimeType = QString())
     {
         // We want even files to have a proper URL
         const auto resource = _resource.startsWith(QLatin1Char('/')) ? QUrl::fromLocalFile(_resource).toString() : _resource;
@@ -250,7 +254,7 @@ public:
         if (m_itemEntries.contains(resource))
             return;
 
-        auto entry = entryForResource(resource);
+        auto entry = entryForResource(resource, mimeType);
 
         if (!entry || !entry->isValid()) {
             qCDebug(KICKER_DEBUG) << "Entry is not valid!" << resource;
@@ -279,7 +283,10 @@ public:
 
         auto url = entry->url();
 
-        m_itemEntries[resource] = m_itemEntries[entry->id()] = m_itemEntries[url.toString()] = m_itemEntries[url.toLocalFile()] = entry;
+        m_itemEntries[resource] = m_itemEntries[entry->id()] = m_itemEntries[url.toString()] = entry;
+        if (!url.toLocalFile().isEmpty()) {
+            m_itemEntries[url.toLocalFile()] = entry;
+        }
 
         auto normalized = normalizedId(resource);
         m_items.insert(index, normalized);
@@ -293,7 +300,7 @@ public:
 
     void removeResult(const QString &resource)
     {
-        auto normalized = normalizedId(resource);
+        const auto normalized = normalizedId(resource);
 
         // If we know this item will not really be removed,
         // but only that activities it is on have changed,
@@ -305,13 +312,13 @@ public:
 
         qCDebug(KICKER_DEBUG) << "Removing result" << resource;
 
-        auto index = m_items.indexOf(normalizedId(resource));
+        auto index = m_items.indexOf(normalized);
 
         if (index == -1)
             return;
 
         beginRemoveRows(QModelIndex(), index, index);
-        auto entry = m_itemEntries[resource];
+        const auto entry = m_itemEntries[resource];
         m_items.removeAt(index);
 
         // Removing the entry from the cache
@@ -512,14 +519,14 @@ void KAStatsFavoritesModel::setEnabled(bool enable)
 
 QStringList KAStatsFavoritesModel::favorites() const
 {
-    qWarning() << "KAStatsFavoritesModel::favorites returns nothing, it is here just to keep the API backwards-compatible";
+    qCWarning(KICKER_DEBUG) << "KAStatsFavoritesModel::favorites returns nothing, it is here just to keep the API backwards-compatible";
     return QStringList();
 }
 
 void KAStatsFavoritesModel::setFavorites(const QStringList &favorites)
 {
     Q_UNUSED(favorites);
-    qWarning() << "KAStatsFavoritesModel::setFavorites is ignored";
+    qCWarning(KICKER_DEBUG) << "KAStatsFavoritesModel::setFavorites is ignored";
 }
 
 bool KAStatsFavoritesModel::isFavorite(const QString &id) const
